#!/bin/bash

# Global test result (default = 0 : ok)
export GLOBALRES=0

VERBOSE=
while getopts v OPTION
do
case $OPTION in
    v) VERBOSE=yes ;;
esac
done


PLOG='/var/log/parsec/kernel.mlog'
TMPFILE="/tmp/file-$$"
starttime=`date +%y%m%d%H%M%S`

echo -n `gettext "Execution of audit system..."` 1>&2
systemctl stop parlogd.service >/dev/null 2>&1
sleep 3
systemctl start parlogd.service >/dev/null 2>&1

if [ ! $? -eq 0 ]; then
    echo `gettext "Can't execute audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	echo `gettext "PASS"` 1>&2
fi

echo `gettext "# Testing audit system"`

echo -n `gettext "Setting audit flags to /tmp dir "`$TMPFILE"..." 1>&2
setfaud -m o:c /tmp
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't set audit flags to /tmp dir "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	echo `gettext "PASS"` 1>&2
fi

touch $TMPFILE

if [ ! $? -eq 0 ]; then
    echo `gettext "Can't create file "`$TMPFILE 1>&2
    exit 1
fi

# Subtest - set flags
echo -n `gettext "Setting audit flags to file "`$TMPFILE"..." 1>&2
setfaud -m o:oxudnarmc $TMPFILE
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't set audit flags to file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	echo `gettext "PASS"` 1>&2
fi


# Subtest - create open event
echo -n `gettext "Creation of open event "`$TMPFILE"..." 1>&2
cat $TMPFILE >/dev/null
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't open file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - create chmod event
echo -n `gettext "Creation of chmod event "`$TMPFILE"..." 1>&2
chmod +x $TMPFILE
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't chmod file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - create chown event
echo -n `gettext "Creation of chown event "`$TMPFILE"..." 1>&2
chown root:root $TMPFILE
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't chmod file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - create audit event
echo -n `gettext "Creation of setfaud event "`$TMPFILE"..." 1>&2
setfaud -m o:oxudnarmc $TMPFILE
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't setfaud file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - create setacl event
echo -n `gettext "Creation of setacl event "`$TMPFILE"..." 1>&2
setfacl -m u:root:r $TMPFILE
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't setfacl file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - create parsec_chmac event
echo -n `gettext "Creation of parsec_chmac event "`$TMPFILE"..." 1>&2
setfmac -s 0:0 $TMPFILE
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't parsec_chmac file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - create exec event
echo -n `gettext "Creation of exec event "`$TMPFILE"..." 1>&2
`/$TMPFILE`
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't exec file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - create unlnik event
echo -n `gettext "Creation of unlink event "`$TMPFILE"..." 1>&2
rm $TMPFILE
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't delete file "`$TMPFILE 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	sleep 1
	echo `gettext "PASS"` 1>&2
fi

# Subtest - stop
echo -n `gettext "Stopping audit service..."` 1>&2
systemctl stop parlogd.service >/dev/null 2>&1
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't stop audition service"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	echo `gettext "PASS"` 1>&2
fi

echo -n `gettext "Removing audit flags from /tmp dir "`"..." 1>&2
setfaud -b /tmp
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't remove audit flags from /tmp dir "` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	echo `gettext "PASS"` 1>&2
fi


currenttime=`date +%y%m%d%H%M%S`
timerange="$starttime-$currenttime"
TMPBASE=`basename $TMPFILE`


# Subtest - search open
echo `gettext "Searching for open messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep open`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search exec
echo `gettext "Searching for exec messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep exec`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search unlnik
echo `gettext "Searching for unlink messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep unlink`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search chmod
echo `gettext "Searching for chmod messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep chmod`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search chown
echo `gettext "Searching for chown messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep chown`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search setacl
echo `gettext "Searching for setacl messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep setacl`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search audit
echo `gettext "Searching for audit messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep parsec_chaud`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search parsec_chmac
echo `gettext "Searching for mac  messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep parsec_chmac`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

# Subtest - search create
echo `gettext "Searching for create  messages within log..."` 1>&2
log=`parselog $PLOG -t$timerange | grep $TMPBASE | grep create`
if [ "$log" == "" ]; then
    echo `gettext "Incorrect work of audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi


# Subtest -
echo -n `gettext "Execution of audit system..."` 1>&2
systemctl start parlogd.service >/dev/null 2>&1
if [ ! $? -eq 0 ]; then
    echo `gettext "Can't execute audit system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	echo `gettext "PASS"` 1>&2
fi

rm -f $TMPFILE
exit $GLOBALRES
