#!/bin/bash

TESTUSER="audittestuser"	#testuser
TMPFILE="/tmp/file-$$"	#testfile
export GLOBALRES="0"	#global result
PLOG="/var/log/parsec/kernel.mlog"	#log file


VERBOSE=
while getopts v OPTION
do
case $OPTION in
    v) VERBOSE=yes ;;
esac
done

#backup audit file
cp $PLOG ${PLOG}.bak
echo "" > $PLOG
cp /etc/parsec/audit /etc/parsec/audit.bak

#add new testuser and set aud flags for testuser
echo  `gettext "prepare for test..."`
echo  `gettext "add testuser and set audit flags"`
useradd -m $TESTUSER 
echo `gettext "test audit for user :"` $TESTUSER
passwd -d $TESTUSER > /dev/null
useraud -m $TESTUSER ocxudnarhwepm:ocxudnarhwepm  #ocxudntligarmphew - all flags
echo `gettext "done"`

#subtest -  uid gid (ig)
echo `gettext "subtest - uid gid"`
useraud root ig > /dev/null
su -c "su -- $TESTUSER  -c true"
sleep 1
log=`kernlog | grep su | grep "setuid"`
if [ "$log" == "" ] ; then
        echo `gettext "no setuid event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
                echo -n `gettext "found: "`
                echo  $log
        fi
        echo -n `gettext "found event - uid... "`
        echo `gettext "PASS"`
fi
log=`kernlog | grep su | grep "setgid"`
if [ "$log" == "" ] ; then
        echo `gettext "no setgid event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
                echo -n `gettext "found: "`
                echo  $log
        fi
        echo -n `gettext "found event - gid... "`
        echo `gettext "PASS"`
fi

#subtest -  module (l)
echo `gettext "subtest - module"`
useraud root l > /dev/null
su -c "modprobe crc7"
sleep 1
log=`kernlog | grep crc7 | grep "init_module"`
if [ "$log" == "" ] ; then
        echo `gettext "no modules event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
                echo -n `gettext "found: "`
                echo  $log
        fi
        echo -n `gettext "found event - init_module... "`
        echo `gettext "PASS"`
fi
su -c "rmmod crc7"
sleep 1
log=`kernlog | grep crc7 | grep "delete_module"`
if [ "$log" == "" ] ; then
        echo `gettext "no modules event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
                echo -n `gettext "found: "`
                echo  $log
        fi
        echo -n `gettext "found event - delete_module... "`
        echo `gettext "PASS"`
fi

#subtest - create file (c)
echo `gettext "subtest - create file"`
su $TESTUSER -c "touch $TMPFILE"
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "create"`
if [ "$log" == "" ] ; then
        echo `gettext  "no create event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - create... "`
        echo `gettext "PASS"`
fi

#subtest -  mac(m)
echo `gettext "subtest - mac"`
useraud root m > /dev/null
su -c "/usr/sbin/pdpl-file 255:1:fffffffffffffff:0 $TMPFILE" 2> /dev/null
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "255:1:0xfffffffffffffff:0x0"`
if [ "$log" == "" ] ; then
        echo `gettext "no mac event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - mac... "`
        echo `gettext "PASS"`
fi

#subtest -  mac (m)
echo `gettext "subtest - mac"`
su -c "/usr/sbin/pdpl-file 0:0:0:0 $TMPFILE"
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "0:0:0x0:0x0"`
if [ "$log" == "" ] ; then
        echo `gettext "no mac event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
                echo -n `gettext "found: "`
                echo  $log
        fi
        echo -n `gettext "found event - mac... "`
        echo `gettext "PASS"`
fi

#subtest - open file (o)
echo `gettext "subtest - open file"`
su $TESTUSER -c "cat $TMPFILE"
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "open"`
if [ "$log" == "" ] ; then
        echo `gettext "no open event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - open... "`
        echo `gettext "PASS"`
fi

#subtest - exec (x)
echo `gettext "subtest - exec programm"`
su $TESTUSER -c "/bin/date > /dev/null"
sleep 1
log=`kernlog | grep "/bin/date" | grep "exec"`
if [ "$log" == "" ] ; then
        echo `gettext "no exec event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - exec... "`
        echo `gettext "PASS"`
fi

#subtest - delete (u)
#echo `gettext "subtest - delete file"`
#su $TESTUSER -c "cp $TMPFILE ${TMPFILE}1 ; rm -f ${TMPFILE}1"
#sleep 1
#log=`kernlog | grep "$TMPFILE" | grep "unlink"`
#if [ "$log" == "" ] ; then
#        echo `gettext "no delete event in kernlog"` 1>&2
#        echo `gettext "FAIL"` 1>&2
#        GLOBALRES=1
#else
#        if [ $VERBOSE ]; then
#            echo -n `gettext "found: "`
#            echo  $log
#        fi
#        echo -n `gettext "found event - delete... "`
#        echo `gettext "PASS"`
#fi

#subtest - chmod (d)
echo `gettext "subtest - chmod"`
su $TESTUSER -c "chmod a=rwx $TMPFILE"
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "chmod"`
if [ "$log" == "" ] ; then
        echo `gettext "no chmod event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - chmod... "`
        echo `gettext "PASS"`
fi

#subtest - chown (n)
echo `gettext "subtest - chown"`
su $TESTUSER -c "chown root $TMPFILE 2> /dev/null"
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "chown"`
if [ "$log" == "" ] ; then
        echo `gettext "no chown event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - chown... "`
        echo `gettext "PASS"`
fi

#subtest - net (w)
echo `gettext "subtest - net"`
su $TESTUSER -c "ping -c2 localhost &> /dev/null"
sleep 1
log=`kernlog | grep "ping" | grep "connect"`
if [ "$log" == "" ] ; then
        echo `gettext "no net event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - net... "`
        echo `gettext "PASS"`
fi

#subtest - chroot (h)
echo `gettext "subtest - chroot"`
su $TESTUSER -c "/usr/sbin/chroot /mnt 2> /dev/null"
sleep 1
log=`kernlog | grep "/mnt" | grep "chroot"`
if [ "$log" == "" ] ; then
        echo `gettext "no chroot event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - chroot... "`
        echo `gettext "PASS"`
fi

#subtest - rename (e)
echo `gettext "subtest - rename"`
su $TESTUSER -c "cp $TMPFILE ${TMPFILE}2 ; mv ${TMPFILE}2 ${TMPFILE}3"
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "rename"`
if [ "$log" == "" ] ; then
	echo `gettext "no rename event in kernlog"` 1>&2
	echo `gettext "FAIL"` 1>&2
	GLOBALRES=1
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo -n `gettext "found event - rename... "`
	echo `gettext "PASS"`
fi

#subtest - cap (p)
echo `gettext "subtest - capabilities"`
usercaps -f $TESTUSER > /dev/null
#su $TESTUSER -c "pscaps `ps | grep bash | sed /bash/q | awk '{print $1}'` 0 0 0 2> /dev/null"
su $TESTUSER -c "pscaps `echo $$` 0 0 0 2> /dev/null"
        sleep 1
log=`kernlog | grep "capset"`
if [ "$log" == "" ] ; then
        echo `gettext "no cap event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - cap... "`
        echo `gettext "PASS"`
fi

#subtest -  audit (a)
echo `gettext "subtest - audit"`
#useraud root a
su $TESTUSER -c "/usr/sbin/setfaud -m o:o:o $TMPFILE"
sleep 1
log=`kernlog | grep "$TMPFILE" | grep "chaud"`
if [ "$log" == "" ] ; then
        echo `gettext "no ch_audit event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - ch_audit... "`
        echo `gettext "PASS"`
fi

#subtest -  acl(r)
echo `gettext "subtest - acl"`
#useraud root r
su $TESTUSER -c "/usr/bin/setfacl -m u:root:rwx $TMPFILE"
sleep 1
log=`kernlog | grep "file-$$" | grep "setacl"`
if [ "$log" == "" ] ; then
        echo `gettext "no acl event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - acl... "`
        echo `gettext "PASS"`
fi

#subtest -  mount (t)
echo `gettext "subtest - mount"`
useraud root t  > /dev/null
su -c "mount /home /mnt 2> /dev/null"
sleep 1
log=`kernlog | grep "/mnt" | grep "mount"`
if [ "$log" == "" ] ; then
        echo `gettext "no mount event in kernlog"` 1>&2
        echo `gettext "FAIL"` 1>&2
        GLOBALRES=1
else
        if [ $VERBOSE ]; then
            echo -n `gettext "found: "`
            echo  $log
        fi
        echo -n `gettext "found event - mount... "`
        echo `gettext "PASS"`
fi













#end test

echo "Check value"
echo $GLOBALRES
if [ $GLOBALRES == 0 ] ; then 
	echo `gettext "Test complete. Process audit works correctly"`
else
	echo `gettext "FAIL"`
fi

rm -f $TMPFILE ${TMPFILE}3
usercaps -d $TESTUSER
deluser -q --remove-home  $TESTUSER
useraud -d root 
cp ${PLOG}.bak $PLOG
cp /etc/parsec/audit.bak /etc/parsec/audit
exit $GLOBALRES	
